@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-""" Batch Video Size Reduction (BVSR).
+""" Batch Video Size Reduction (BVSR) using ffmpeg.
 
 A python script to reduce the size of all videos in a source folder while keeping the same folder structure.
 
@@ -15,34 +15,13 @@ FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 You should have received a copy of the GNU General Public License along with
 this program. If not, see <http://www.gnu.org/licenses/>.
 
+Resources and credits:
 https://unix.stackexchange.com/questions/28803/how-can-i-reduce-a-videos-size-with-ffmpeg/289322#289322
 https://slhck.info/video/2017/02/24/crf-guide.html
 https://trac.ffmpeg.org/wiki/Encode/H.264
 https://en.wikipedia.org/wiki/Bit_rate
 """
 
-__author__ = "Abdeladim S."
-__copyright__ = "Copyright 2022, "
-__deprecated__ = False
-__license__ = "GPLv3"
-__maintainer__ = __author__
-__github__ = "https://github.com/abdeladim-s/bvsr"
-__version__ = '0.1.2'
-
-__header__ = f"""
-
-██████╗ ██╗   ██╗███████╗██████╗ 
-██╔══██╗██║   ██║██╔════╝██╔══██╗
-██████╔╝██║   ██║███████╗██████╔╝
-██╔══██╗╚██╗ ██╔╝╚════██║██╔══██╗
-██████╔╝ ╚████╔╝ ███████║██║  ██║
-╚═════╝   ╚═══╝  ╚══════╝╚═╝  ╚═╝
-                            
-version: {__version__}     
-===================================
-
-"""
-
 from pathlib import Path
 from tqdm import tqdm
 import argparse
@@ -57,9 +36,33 @@ import shutil
 import os
 import mimetypes
 from os.path import exists
+import importlib.metadata
 
 gevent.monkey.patch_all(thread=False)
 
+__author__ = "Abdeladim S."
+__copyright__ = "Copyright 2022, "
+__deprecated__ = False
+__license__ = "GPLv3"
+__maintainer__ = __author__
+__github__ = "https://github.com/abdeladim-s/bvsr"
+__version__ = importlib.metadata.version('bvsr')
+
+
+__header__ = f"""
+
+██████╗ ██╗   ██╗███████╗██████╗ 
+██╔══██╗██║   ██║██╔════╝██╔══██╗
+██████╔╝██║   ██║███████╗██████╔╝
+██╔══██╗╚██╗ ██╔╝╚════██║██╔══██╗
+██████╔╝ ╚████╔╝ ███████║██║  ██║
+╚═════╝   ╚═══╝  ╚══════╝╚═╝  ╚═╝
+
+Batch Video Size Reduction (BVSR) using ffmpeg
+Version: {__version__}               
+===================================
+"""
+
 VIDEO_BITRATES = {
     # https://en.wikipedia.org/wiki/Bit_rate
     'videophone': 16_000,  # videophone quality (minimum necessary for a consumer-acceptable "talking head" picture)
@@ -432,4 +435,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
